#!/bin/ksh
#> This script will install LucentUMTS - LuUMTS_CS module
#> patch: 5.0.8.0.20.1
#

# variables used after <productVersion> and <wsVersion> drop.
export NEPATCH_START_DIR=`pwd`
export ARCHIVE_DIR=$NEPATCH_START_DIR/Archive
export BACKUP_DIR=$NEPATCH_START_DIR/Backup

########################################################
# Check system values required for this module but not checked by the
# main installer.
if [[ -z $FLEXPM_HOME ]]; then
  echo "+> FLEXPM_HOME environment is not defined"
  echo "+> Please ensure that this is defined and then reinstall upgrade"
  echo ""
  exit 2
fi

if [[ ! -d $FLEXPM_HOME ]]; then
  echo "+> FLEXPM_HOME environment value '$FLEXPM_HOME'"
  echo "+> is not a valid directory. Please check this value"
  echo ""
  exit 2
fi

########################################################
# Check system values required for this module but not checked by the
# main installer.
if [[ -z $LuUMTS_CS_HOME ]]; then
  echo "+> LuUMTS_CS_HOME environment is not defined"
  echo "+> Please ensure that this is defined and then reinstall upgrade"
  echo ""
  exit 2
fi

if [[ ! -d $LuUMTS_CS_HOME ]]; then
  echo "+> LuUMTS_CS_HOME environment value '$LuUMTS_CS_HOME'"
  echo "+> is not a valid directory. Please check this value"
  echo ""
  exit 2
fi

export ARCHIVE_DIR=$NEPATCH_START_DIR/../ProspectBase/Archive
export BACKUP_DIR=$NEPATCH_START_DIR/../ProspectBase/Backup

########################################################
# Begin the upgrade
echo "+ Installing ProspectBase component upgrades ... "
date +"+ Component upgrade is started at %T, %D ... "
echo "ARCHIVE_DIR: $ARCHIVE_DIR";
echo "BACKUP_DIR : $BACKUP_DIR";

cd ${NEPATCH_START_DIR}
if [ ! -d $BACKUP_DIR ]
then
  mkdir -p $BACKUP_DIR
fi


echo "+ Backing up original ProspectBase module files ..."
cd $FLEXPM_HOME
for file in `gtar -tzf ${NEPATCH_START_DIR}/PB_1.0.tgz`
do
  if [ -f $file ]
  then
    if [ ! -d ${ARCHIVE_DIR}/`dirname $file` ]
    then
      mkdir -p ${ARCHIVE_DIR}/`dirname $file`
    fi
    cp $file ${ARCHIVE_DIR}/`dirname $file`
    chmod +w $file
  fi
done

cd $ARCHIVE_DIR
gtar -czf ../PB_Module_Archive_`date '+%y%m%d_%H%M%S'`.tar.gz *
cd $ARCHIVE_DIR/../
rm -rf ${ARCHIVE_DIR}
mv -f PB_Module_Archive*.tar.gz $BACKUP_DIR/
cd $FLEXPM_HOME

echo "+ Installing new/updated files for ProspectBase module ..."
gtar -xvzf ${NEPATCH_START_DIR}/PB_1.0.tgz

chmod ugo+x  $FLEXPM_HOME/vendor/Common/NE/1.3/scripts/filedecode.pl

date +"+ ProspectBase component upgrade is completed at %T, %D ....."
echo ""
########################################################
export ARCHIVE_DIR=$NEPATCH_START_DIR/Archive
export BACKUP_DIR=$NEPATCH_START_DIR/Backup

echo "ARCHIVE_DIR: $ARCHIVE_DIR";
echo "BACKUP_DIR : $BACKUP_DIR";

# Begin the upgrade
echo "+ Installing LuUMTS_CS component upgrades ... "
date +"+ Component upgrade is started at %T, %D ... "

cd ${NEPATCH_START_DIR}
if [ ! -d $BACKUP_DIR ]
then
  mkdir $BACKUP_DIR
fi



echo "+ Backing up original LuUMTS_CS module files ..."
cd $LuUMTS_CS_HOME
for file in `gtar -tzf ${NEPATCH_START_DIR}/LuUMTS_CS_1.0.tgz`
do
  if [ -f $file ]
  then
    if [ ! -d ${ARCHIVE_DIR}/`dirname $file` ]
    then
      mkdir -p ${ARCHIVE_DIR}/`dirname $file`
    fi
    cp $file ${ARCHIVE_DIR}/`dirname $file`
    chmod +w $file
  fi
done

cd $NEPATCH_START_DIR/Archive
gtar -czf ../Module_Archive_`date '+%y%m%d_%H%M%S'`.tar.gz *
cd $NEPATCH_START_DIR
rm -rf ${ARCHIVE_DIR}
mv -f Module_Archive*.tar.gz $BACKUP_DIR/
cd $LuUMTS_CS_HOME

echo "+ Installing new/updated files for LuUMTS_CS module ..."
gtar -xvzf ${NEPATCH_START_DIR}/LuUMTS_CS_1.0.tgz

cd $LuUMTS_CS_HOME/peik
make dict_update

cd $LuUMTS_CS_HOME/vendor/Lucent/UMTS_CS/1.3/LuUMTS_CS_loader/CallServer0302_pm/config
make clean
make all

cd $LuUMTS_CS_HOME/vendor/Lucent/UMTS_CS/1.3/LuUMTS_CS_loader/CallServer_pm/scripts/PreProcess
chmod ugo+x *pm

date +"+ LuUMTS_CS component upgrade is completed at %T, %D ....."
echo ""
exit 0
$
